==> warperia_Blood-Shield-Tracker_2025-11-04_16-54-59.zip: BloodShieldTracker/Locale/esES.lua <==
local L = LibStub("AceLocale-3.0"):NewLocale("BloodShieldTracker", "esES", false)

if not L then return end

L["Absorbed/Total Shields/Percent:"] = "Absorbido/Escudos Totales/Porcentaje"
L["Appearance"] = "Apariencia"
L["Applied Sound"] = "Sonido de activacion"
L["AppliedSoundDesc"] = "El sonido a reproducir cuando el Escudo de Sangre se active."
L["Bar Color"] = "Color de la Barra"
L["Bar Depleted Color"] = "Color de Barra Agotada"
L["BarTexture_OptionDesc"] = "Textura a usar por la barra." -- Needs review
L["Blizzard"] = true
L["Blood Shield"] = "Escudo de Sangre" -- Needs review
L["Blood Shield Bar"] = "Barra del Escudo de Sangre"
L["BloodShieldBarColor_OptionDesc"] = "Cambia el color de la barra del escudo de sangre."
L["BloodShieldBar_Desc"] = "La Barra del Escudo de Sangre es mostrada cada vez que un Escudo de Sangre esta activo en el Death Knight. La barra calculara el valor inicial y maximo del escudo y vigilara el valor restante del escudo basado en el daño entrante absorbido. Cuando el escudo es eliminado del DK, la barra desaparecera."
L["Blood Shield bar height"] = "Altura de la barra del Escudo de Sangre"
L["BloodShieldBarTextColor_OptionDesc"] = "Cambia el color del texto de la barra del escudo de sangre."
L["Blood Shield bar width"] = "Ancho de la barra del Escudo de Sangre"
L["Blood Shield Data"] = "Datos del Escudo de Sangre"
L["BloodShieldDepletedBarColor_OptionDesc"] = "Cambia el color de agotado de la Barra de Escudo. Esto cambiara el color a mostrar por la parte de la barra sin rellenar."
L["Blood Shield Max Value"] = "Valor del Escudo de Sangre Maximo"
L["BloodShieldTracker_Desc"] = "Blood Shield Tracker es un addon para Tanques DK Sangre. Este proporciona una barra para vigilar el Escudo de Sangre y una barra para vigilar la curacion estimada del Golpe Letal."
L["Blood Shield Usage"] = "Uso del Escudo de Sangre"
L["Change the height of the blood shield bar."] = "Cambia la altura de la barra del Escudo de Sangre."
L["Change the height of the estimated healing bar."] = "Cambia la altura de la barra de curacion estimada."
L["Change the width of the blood shield bar."] = "Cambia la altura de la barra del escudo de sangre."
L["Change the width of the estimated healing bar."] = "Cambia el ancho de la barra de curacion estimada."
L["Colors"] = "Colores"
L["Colors for Minimum Heal"] = "Colores para Curacion Minima"
L["Colors for Optimal Heal"] = "Colores para Curacion Optima"
L["Config Mode"] = "Modo de Configuracion"
L["Could not determine talents."] = "No puedo determinar los talentos."
L["Current and Maximum"] = "Actual y Maximo"
L["Dimensions"] = "Dimensiones"
L["Enabled"] = "Activada"
L["Enable the Blood Shield Bar."] = "Activa la Barra del Escudo de Sangre."
L["Enable the Estimated Healing Bar."] = "Activa la Barra de Curacion Estimada."
L["EstHealBarMinBackgroundColor_OptionDesc"] = "Cambia el color de fondo de la Barra de Curacion Estimada para el minimo de curacion del Golpe Letal."
L["EstHealBarMinColor_OptionDesc"] = "Cambia el color de la Barra de Curacion Estimada para la curacion minima del Golpe Letal."
L["EstHealBarMinTextColor_OptionDesc"] = "Cambia el color del texto de la Barra de Curacion Estimada para la curacion minima del Golpe Letal."
L["EstHealBarOptColor_OptionDesc"] = "Cambia el color de la Barra de Curacion Estimada para la curacion optima del Golpe Letal (Ej. Mayor que el minimo)."
L["EstHealBarOptTextColor_OptionDesc"] = "Cambia el color de texto de la Barra de Curacion Estimada para la curacion optima del Golpe Letal (Ej. Mayor que el minimo)."
L["EstHealBarShowText_OptDesc"] = "Alterna la visualizacion del texto en la barra de curacion estimada. Si el texto no es mostrado, solo la curacion estimada sera mostrada."
L["Estimated Healing Bar"] = "Barra de Curacion Estimada"
L["EstimatedHealingBar_Desc"] = "La Barra de Curacion Estimada proporciona el valor de la curacion del Golpe Letal si el Golpe Letal es usado en ese momento. Si la curacion fuera la minima (ej. 10% de la vida maxima) entonces la barra estara roja por defecto. Si la curacion es mayor que el minimo, entonces la barra se vuelve verde por defecto. Puedes usar esos dos colores para saber cuando es el mejor momento para el Golpe Letal. Puedes configurar los colores de ambos estados abajo."
L["Estimated Healing bar height"] = "Altura de la barra de curacion estimada"
L["Estimated Healing bar width"] = "Ancho de la barra de curacion estimada"
L["Fight Duration:"] = "Duracion del Combate"
L["Fixed"] = "Fijado" -- Needs review
L["Font"] = "Fuente"
L["FontMonochrome_OptionDesc"] = "Cambia si la fiente es renderizada sin anti-aliasing"
L["FontOutline_OptionDesc"] = "Cambia si un contorno negro se muestra en torno a la fuente."
L["Font size"] = "Tamaño de la fuente de letra"
L["Font size for the bars."] = "Tamaño de la fuente de letra de las barras."
L["FontThickOutline_OptionDesc"] = "Alterna si la fuente se muestra con un contorno negro y grueso"
L["Font to use."] = "Fuente a usar."
L["Font to use for this panel."] = "Fuente para usar con este panel."
L["Full"] = "Completo"
L["General Options"] = "Opciones Generales"
L["HealBarText"] = "Cur. Est."
L["Height"] = "Altura"
L["HideOOC_OptionDesc"] = "Oculta la Barra de Curacion Estimada cuando se esta fuera de combate."
L["Hide out of combat"] = "Ocultar fuera de combate"
L["Last Fight Data"] = "Datos del Ultimo Combate"
L["Latency"] = "Latencia" -- Needs review
L["Left"] = "Izquierda"
L["Lock bar"] = "Bloquear Barra"
L["Lock damage bar"] = "Bloquear barra de daño"
L["Lock estimated healing bar"] = "Bloquear la barra de curacion estimada"
L["Lock shield bar"] = "Bloquear barra de escudo"
L["Lock status bar"] = "Bloquear barra de estado"
L["Lock the damage bar from moving."] = "Boquea la posicion de la barra de daño."
L["Lock the estimated healing bar from moving."] = "Bloquea la posicion de la barra de estado."
L["Lock the shield bar from moving."] = "Bloquea la posicion de la barra de escudo."
L["Lock the status bar from moving."] = "Boquea la posicion de la barra de estado."
L["Minimap Button"] = "Boton de Minimapa"
L["Minimum Bar Background Color"] = "Color de Fondo de Barra Minimo"
L["Minimum Bar Color"] = "Color de la Barra Minimo"
L["Minimum Text Color"] = "Color del texto minimo"
L["Min - Max / Avg:"] = "Min - Max / Medio:"
L["Mode"] = "Modo" -- Needs review
L["Monochrome"] = "Monocromo"
L["None"] = "Nada" -- Needs review
L["Number of Minimum Shields:"] = "Numero de Escudos Minimo:"
L["Only Current"] = "Solo Actual"
L["Only for Blood DK"] = "Solo para DK Sangre"
L["OnlyForBlood_OptionDesc"] = "Alterna si el addon esta solo habilitado para DKs Sangre o si esta habilitado para cualquier DK. La barra de Curacion Estimada solo funcionara para los \"DKs no-sangre\" si es establecida como falso."
L["Only Maximum"] = "Solo Maximo"
L["Only Percent"] = "Solo Porcentaje"
L["Optimal Bar Color"] = "Color de Barra Optimo"
L["Optimal Text Color"] = "Color de Texto Optimo"
L["Outline"] = "Contorno"
L["Position"] = "Posicion"
L["Removed Sound"] = "Sonido de eliminacion"
L["RemovedSoundDesc"] = "El sonido a reproducir cuando el Escudo de Sangre es eliminado."
L["Right"] = "Derecha"
L["Scale"] = "Escala"
L["ScaleDesc"] = "Establece la escala de la barra."
L["seconds"] = "segundos"
L["Shield Frequency:"] = "Frecuencia de Escudos"
L["ShieldSoundEnabledDesc"] = "Activa la reproduccion de sonidos para el Escudo de Sangre."
L["Shields Total/Refreshed/Removed:"] = "Escudos Totales/Actualizados/Eliminados:"
L["ShieldTextFormat_OptionDesc"] = "Especifica el formato de texto de la barra de escudo."
L["Shift + Left-Click to reset."] = "Mayus + Click-Derecho para resetear."
L["ShowBar"] = "Mostrar fondo"
L["ShowBarDesc"] = "Muestra la barra y el borde, cuando se desactiva solo el texto aparecera."
L["ShowBorder"] = "Mostrar Borde"
L["ShowBorderDesc"] = "Muestra el borde alrededor de la barra."
L["Show Text"] = "Mostrar Texto"
L["Show Time"] = "Mostrar Tiempo"
L["ShowTime_OptionDesc"] = "Alterna si el tiempo restante es mostrado en la barra."
L["Sound"] = "Sonido"
L["StatusBarTexture"] = "Textura de la Barra de Estado"
L["Text Color"] = "Color del Texto"
L["Text Format"] = "Formato de Texto"
L["Texture"] = "Textura"
L["Thick Outline"] = "Grosor del contorno"
L["TimePosition_OptionDesc"] = "Posicion en la barra para mostrar el tiempo restante."
L["Time Remaining"] = "Tiempo restante"
L["Toggle config mode"] = "Alternar modo de configuracion"
L["Toggles the display of informational messages"] = [=[Alterna la visualizacion de mensajes informativos
]=]
L["Toggle the minimap button"] = "Alternar boton de minimapa"
L["Total Data"] = "Datos Totales"
L["Usage Min - Max / Avg:"] = "Uso Min - Max / Medio:"
L["Use Aura"] = "Aura"
L["UseAura_OptionDesc"] = "Alterna si la barra del Escudo de Sangre utiliza el aura o los datos de registro de combate"
L["Verbose"] = "Informacion detallada"
L["Width"] = "Ancho"

==> warperia_Blood-Shield-Tracker_2025-12-12_15-56-07.zip: BloodShieldTracker/Locale/esES.lua <==
local L = LibStub("AceLocale-3.0"):NewLocale("BloodShieldTracker", "esES", false)

if not L then return end

L["Absorbed/Total Shields/Percent:"] = "Absorbido/Escudos Totales/Porcentaje"
L["Appearance"] = "Apariencia"
L["Applied Sound"] = "Sonido de activacion"
L["AppliedSoundDesc"] = "El sonido a reproducir cuando el Escudo de Sangre se active."
L["Bar Color"] = "Color de la Barra"
L["Bar Depleted Color"] = "Color de Barra Agotada"
L["BarTexture_OptionDesc"] = "Textura a usar por la barra."
L["Blizzard"] = true
L["Blood Shield"] = "Escudo de Sangre"
L["Blood Shield Bar"] = "Barra del Escudo de Sangre"
L["Blood Shield bar height"] = "Altura de la barra del Escudo de Sangre"
L["Blood Shield bar width"] = "Ancho de la barra del Escudo de Sangre"
L["Blood Shield Data"] = "Datos del Escudo de Sangre"
L["Blood Shield Max Value"] = "Valor del Escudo de Sangre Maximo"
L["Blood Shield Usage"] = "Uso del Escudo de Sangre"
L["BloodShieldBar_Desc"] = "La Barra del Escudo de Sangre es mostrada cada vez que un Escudo de Sangre esta activo en el Death Knight. La barra calculara el valor inicial y maximo del escudo y vigilara el valor restante del escudo basado en el daño entrante absorbido. Cuando el escudo es eliminado del DK, la barra desaparecera."
L["BloodShieldBarColor_OptionDesc"] = "Cambia el color de la barra del escudo de sangre."
L["BloodShieldBarTextColor_OptionDesc"] = "Cambia el color del texto de la barra del escudo de sangre."
L["BloodShieldDepletedBarColor_OptionDesc"] = "Cambia el color de agotado de la Barra de Escudo. Esto cambiara el color a mostrar por la parte de la barra sin rellenar."
L["BloodShieldTracker_Desc"] = "Blood Shield Tracker es un addon para Tanques DK Sangre. Este proporciona una barra para vigilar el Escudo de Sangre y una barra para vigilar la curacion estimada del Golpe Letal."
L["Change the height of the blood shield bar."] = "Cambia la altura de la barra del Escudo de Sangre."
L["Change the height of the estimated healing bar."] = "Cambia la altura de la barra de curación estimada."
L["Change the width of the blood shield bar."] = "Cambia la altura de la barra del escudo de sangre."
L["Change the width of the estimated healing bar."] = "Cambia el ancho de la barra de curación estimada."
L["Colors"] = "Colores"
L["Colors for Minimum Heal"] = "Colores para Curacion Minima"
L["Colors for Optimal Heal"] = "Colores para Curacion Optima"
L["Config Mode"] = "Modo de Configuracion"
L["Could not determine talents."] = "No puedo determinar los talentos."
L["Current and Maximum"] = "Actual y Maximo"
L["Dimensions"] = "Dimensiones"
L["Enable the Blood Shield Bar."] = "Activa la Barra del Escudo de Sangre."
L["Enable the Estimated Healing Bar."] = "Activa la Barra de Curacion Estimada."
L["Enabled"] = "Activada"
L["EstHealBarMinBackgroundColor_OptionDesc"] = "Cambia el color de fondo de la Barra de Curacion Estimada para el minimo de curacion del Golpe Letal."
L["EstHealBarMinColor_OptionDesc"] = "Cambia el color de la Barra de Curacion Estimada para la curacion minima del Golpe Letal."
L["EstHealBarMinTextColor_OptionDesc"] = "Cambia el color del texto de la Barra de Curacion Estimada para la curacion minima del Golpe Letal."
L["EstHealBarOptColor_OptionDesc"] = "Cambia el color de la Barra de Curacion Estimada para la curacion optima del Golpe Letal (Ej. Mayor que el minimo)."
L["EstHealBarOptTextColor_OptionDesc"] = "Cambia el color de texto de la Barra de Curacion Estimada para la curacion optima del Golpe Letal (Ej. Mayor que el minimo)."
L["EstHealBarShowText_OptDesc"] = "Alterna la visualizacion del texto en la barra de curacion estimada. Si el texto no es mostrado, solo la curacion estimada sera mostrada."
L["Estimated Healing Bar"] = "Barra de Curacion Estimada"
L["Estimated Healing bar height"] = "Altura de la barra de curación estimada"
L["Estimated Healing bar width"] = "Ancho de la barra de curación estimada"
L["EstimatedHealingBar_Desc"] = "La Barra de Curacion Estimada proporciona el valor de la curacion del Golpe Letal si el Golpe Letal es usado en ese momento. Si la curacion fuera la minima (ej. 10% de la vida maxima) entonces la barra estara roja por defecto. Si la curacion es mayor que el minimo, entonces la barra se vuelve verde por defecto. Puedes usar esos dos colores para saber cuando es el mejor momento para el Golpe Letal. Puedes configurar los colores de ambos estados abajo."
L["Fight Duration:"] = "Duracion del Combate"
L["Fixed"] = "Fijado"
L["Font"] = "Fuente"
L["Font size"] = "Tamaño de la fuente de letra"
L["Font size for the bars."] = "Tamaño de la fuente de letra de las barras."
L["Font to use for this panel."] = "Fuente para usar con este panel."
L["Font to use."] = "Fuente a usar."
L["FontMonochrome_OptionDesc"] = "Cambia si la fiente es renderizada sin anti-aliasing"
L["FontOutline_OptionDesc"] = "Cambia si un contorno negro se muestra en torno a la fuente."
L["FontThickOutline_OptionDesc"] = "Alterna si la fuente se muestra con un contorno negro y grueso"
L["Full"] = "Completo"
L["General Options"] = "Opciones Generales"
L["HealBarText"] = "Cur. Est."
L["Height"] = "Altura"
L["Hide out of combat"] = "Ocultar fuera de combate"
L["HideOOC_OptionDesc"] = "Oculta la Barra de Curacion Estimada cuando se esta fuera de combate."
L["Last Fight Data"] = "Datos del Ultimo Combate"
L["Latency"] = "Latencia"
L["Left"] = "Izquierda"
L["Lock bar"] = "Bloquear Barra"
L["Lock damage bar"] = "Bloquear barra de daño"
L["Lock estimated healing bar"] = "Bloquear la barra de curacion estimada"
L["Lock shield bar"] = "Bloquear barra de escudo"
L["Lock status bar"] = "Bloquear barra de estado"
L["Lock the damage bar from moving."] = "Bloquea la posición de la barra de daño."
L["Lock the estimated healing bar from moving."] = "Bloquea la posicion de la barra de estado."
L["Lock the shield bar from moving."] = "Bloquea la posicion de la barra de escudo."
L["Lock the status bar from moving."] = "Bloquea la posición de la barra de estado."
L["Min - Max / Avg:"] = "Min - Max / Medio:"
L["Minimap Button"] = "Boton de Minimapa"
L["Minimum Bar Background Color"] = "Color de Fondo de Barra Minimo"
L["Minimum Bar Color"] = "Color de la Barra Minimo"
L["Minimum Text Color"] = "Color del texto minimo"
L["Mode"] = "Modo"
L["Monochrome"] = "Monocromo"
L["None"] = "Nada"
L["Number of Minimum Shields:"] = "Numero de Escudos Minimo:"
L["Only Current"] = "Solo Actual"
L["Only for Blood DK"] = "Solo para DK Sangre"
L["Only Maximum"] = "Solo Maximo"
L["Only Percent"] = "Solo Porcentaje"
L["OnlyForBlood_OptionDesc"] = "Alterna si el addon esta solo habilitado para DKs Sangre o si esta habilitado para cualquier DK. La barra de Curacion Estimada solo funcionara para los \"DKs no-sangre\" si es establecida como falso."
L["Optimal Bar Color"] = "Color de Barra Optimo"
L["Optimal Text Color"] = "Color de Texto Optimo"
L["Outline"] = "Contorno"
L["Position"] = "Posicion"
L["Removed Sound"] = "Sonido de eliminacion"
L["RemovedSoundDesc"] = "El sonido a reproducir cuando el Escudo de Sangre es eliminado."
L["Right"] = "Derecha"
L["Scale"] = "Escala"
L["ScaleDesc"] = "Establece la escala de la barra."
L["seconds"] = "segundos"
L["Shield Frequency:"] = "Frecuencia de Escudos"
L["Shields Total/Refreshed/Removed:"] = "Escudos Totales/Actualizados/Eliminados:"
L["ShieldSoundEnabledDesc"] = "Activa la reproduccion de sonidos para el Escudo de Sangre."
L["ShieldTextFormat_OptionDesc"] = "Especifica el formato de texto de la barra de escudo."
L["Shift + Left-Click to reset."] = "Mayus + Click-Derecho para resetear."
L["Show Text"] = "Mostrar Texto"
L["Show Time"] = "Mostrar Tiempo"
L["ShowBar"] = "Mostrar fondo"
L["ShowBarDesc"] = "Muestra la barra y el borde, cuando se desactiva solo el texto aparecera."
L["ShowBorder"] = "Mostrar Borde"
L["ShowBorderDesc"] = "Muestra el borde alrededor de la barra."
L["ShowTime_OptionDesc"] = "Alterna si el tiempo restante es mostrado en la barra."
L["Sound"] = "Sonido"
L["StatusBarTexture"] = "Textura de la Barra de Estado"
L["Text Color"] = "Color del Texto"
L["Text Format"] = "Formato de Texto"
L["Texture"] = "Textura"
L["Thick Outline"] = "Grosor del contorno"
L["Time Remaining"] = "Tiempo restante"
L["TimePosition_OptionDesc"] = "Posicion en la barra para mostrar el tiempo restante."
L["Toggle config mode"] = "Alternar modo de configuracion"
L["Toggle the minimap button"] = "Alternar boton de minimapa"
L["Toggles the display of informational messages"] = [=[Alterna la visualizacion de mensajes informativos
]=]
L["Total Data"] = "Datos Totales"
L["Usage Min - Max / Avg:"] = "Uso Min - Max / Medio:"
L["Use Aura"] = "Aura"
L["UseAura_OptionDesc"] = "Alterna si la barra del Escudo de Sangre utiliza el aura o los datos de registro de combate"
L["Verbose"] = "Informacion detallada"
L["Width"] = "Ancho"
